.. image:: https://img.shields.io/pypi/v/Hond.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/Hond/
.. image:: https://github.com/Uptimedog/Hond/actions/workflows/ci.yml/badge.svg
    :alt: Build Status
    :target: https://github.com/Uptimedog/Hond/actions/workflows/ci.yml

|

========
Hond
========

    Metrics Ingestion and Alerting Reimagined.


Note
====

This project is created and maintained for Uptimedog. see https://github.com/Uptimedog
